@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2014-2022 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2014-2023 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  Copyright 2014-2019 Timur Madzhidov tmadzhidov@gmail.com features and API discussion
 #  Copyright 2014-2019 Alexandre Varnek <varnek@unistra.fr> base idea of CGR approach
 #  This file is part of chython.
@@ -25,16 +25,7 @@ from .reactor import *
 from .utils import *
 
 
-smiles = SMILESRead.create_parser(ignore=True, remap=False)
-xyz = XYZRead.create_parser()
-
-
 pickle_cache = False  # store cached attributes in pickle
 torch_device = 'cpu'  # AAM model device. Change before first `reset_mapping` call!
 
-
-__all__ = ['depict_settings', 'smiles', 'xyz', 'mdl_mol', 'smarts', 'patch_pandas']
-
-if 'INCHIRead' in locals():
-    inchi = INCHIRead.create_parser()
-    __all__.append('inchi')
+__all__ = []
