@@ -36,7 +36,7 @@ def _rules():
     # acid reduction
     r = smiles('[CH3:2][C:1]([OH:3])=[O:4]>>[CH3:2][CH2:1][OH:3]')
     m = smarts('[O;D1:3]')
-    raw_rules.append((r, {3: 4}, m))
+    raw_rules.append((r, {3: 4, 4: 3}, m))
 
     # ester reduction
     r = smiles('[CH3:5][O:3][C:1]([CH3:2])=[O:4]>>[CH3:2][CH2:1][OH:3]')
@@ -57,7 +57,7 @@ def _rules():
 
     # metathesis
     r = smiles('[CH3:1][CH:2]=[CH2:3].[CH3:5][CH:4]=[CH2:6]>>[CH3:5][CH:3]=[CH:2][CH3:1]')
-    raw_rules.append((r, {3: 4}, None))
+    raw_rules.append((r, {3: 4, 4: 3}, None))
 
     rules = []
     for r, f, m in raw_rules:
