@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2018-2022 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2018-2023 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  Copyright 2019 Artem Mukanov <nostro32@mail.ru>
 #  This file is part of chython.
 #
@@ -21,4 +21,4 @@ from .smarts import *
 from .smiles import *
 
 
-__all__ = ['SMILESRead', 'smarts']
+__all__ = ['smiles', 'smarts']
