@@ -74,11 +74,20 @@ class S(Element, PeriodIII, GroupXVI):
     @property
     def _valences_exceptions(self):
         return ((-1, False, 1, ()), (-2, False, 0, ()),  # anions
+                (0, True, 1, ()), (0, True, 3, ()),  # radical OGB-dataset
                 (0, False, 0, ()),  # elemental
+
+                (1, False, 0, ((2, 'C'), (1, 'C'))),
+                (1, False, 0, ((2, 'C'), (1, 'S'))),
+                (1, False, 0, ((2, 'N'), (1, 'C'))),
+
                 (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'C'))),
                 (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'B'))),
-                (1, False, 0, ((1, 'C'), (2, 'C'))),
+                (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'O'))),
+                (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'N'))),
+
                 (1, False, 0, ((2, 'O'), (1, 'C'), (1, 'C'), (1, 'C'))),
+                (1, False, 0, ((2, 'O'), (1, 'C'), (1, 'C'), (1, 'N'))),
 
                 (0, False, 0, ((2, 'O'), (2, 'O'))),
                 (0, False, 0, ((2, 'O'), (2, 'N'))),
@@ -103,6 +112,8 @@ class S(Element, PeriodIII, GroupXVI):
                 (0, False, 0, ((2, 'O'), (1, 'Cl'), (1, 'Cl'))),
                 (0, False, 0, ((2, 'O'), (1, 'Br'), (1, 'Br'))),
 
+                (0, False, 0, ((2, 'O'), (1, 'S'), (1, 'S'))),
+
                 (0, False, 0, ((2, 'O'), (1, 'C'), (1, 'C'))),
                 (0, False, 0, ((2, 'O'), (1, 'C'), (1, 'F'))),
                 (0, False, 0, ((2, 'O'), (1, 'C'), (1, 'Cl'))),
@@ -112,6 +123,7 @@ class S(Element, PeriodIII, GroupXVI):
 
                 (0, False, 0, ((2, 'N'), (1, 'F'), (1, 'F'))),
                 (0, False, 0, ((2, 'N'), (1, 'C'), (1, 'C'))),
+                (0, False, 0, ((2, 'N'), (1, 'C'), (1, 'O'))),
                 (0, False, 0, ((2, 'N'), (1, 'C'), (1, 'Cl'))),
                 (0, False, 0, ((2, 'N'), (1, 'C'), (1, 'S'))),
                 (0, False, 0, ((2, 'N'), (1, 'N'), (1, 'C'))),
@@ -147,8 +159,10 @@ class S(Element, PeriodIII, GroupXVI):
                 (0, False, 0, ((1, 'O'), (1, 'N'), (1, 'C'), (1, 'C'))),
 
                 (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Cl'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'N'), (1, 'N'))),
 
                 (0, False, 0, ((1, 'S'), (1, 'C'), (1, 'C'), (1, 'C'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'C'), (1, 'C'))),
 
                 (0, False, 0, ((2, 'O'), (2, 'O'), (2, 'O'))),
                 (0, False, 0, ((2, 'O'), (2, 'O'), (2, 'C'))),
@@ -196,8 +210,13 @@ class S(Element, PeriodIII, GroupXVI):
                 (0, False, 0, ((2, 'O'), (2, 'C'), (1, 'N'), (1, 'C'))),
                 (0, False, 0, ((2, 'O'), (2, 'C'), (1, 'N'), (1, 'N'))),
 
+                (0, False, 0, ((2, 'N'), (2, 'C'), (1, 'C'), (1, 'O'))),
+
                 (0, False, 0, ((2, 'O'), (2, 'S'), (1, 'O'), (1, 'O'))),  # [S2O3]2-
                 (0, False, 0, ((2, 'O'), (2, 'S'), (1, 'O'), (1, 'C'))),
+                (0, False, 0, ((2, 'O'), (2, 'S'), (1, 'C'), (1, 'C'))),
+
+                (0, False, 0, ((2, 'S'), (2, 'S'), (1, 'O'), (1, 'O'))),
 
                 (0, False, 0, ((1, 'F'), (1, 'F'), (1, 'F'), (1, 'F'), (1, 'F'), (1, 'F'))),
                 (0, False, 0, ((1, 'F'), (1, 'F'), (1, 'F'), (1, 'F'), (1, 'F'), (1, 'O'))),
@@ -230,10 +249,11 @@ class Se(Element, PeriodIV, GroupXVI):
 
     @property
     def _valences_exceptions(self):
-        return ((-1, False, 1, ()),
+        return ((-1, False, 1, ()), (-2, False, 0, ()),
                 (0, False, 0, ()),  # elemental
                 (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'C'))),
                 (1, False, 0, ((1, 'C'), (2, 'C'))),
+
                 (0, False, 0, ((2, 'O'), (2, 'O'))),
                 (0, False, 0, ((2, 'S'), (2, 'S'))),
                 (0, False, 0, ((2, 'N'), (2, 'N'))),
@@ -242,6 +262,16 @@ class Se(Element, PeriodIV, GroupXVI):
                 (0, False, 0, ((2, 'O'), (1, 'Cl'), (1, 'Cl'))),
                 (0, False, 0, ((2, 'O'), (1, 'F'), (1, 'F'))),
                 (0, False, 0, ((2, 'O'), (1, 'C'), (1, 'C'))),
+                (0, False, 0, ((2, 'O'), (1, 'N'), (1, 'C'))),
+                (0, False, 0, ((2, 'O'), (1, 'O'), (1, 'C'))),
+
+                (0, False, 0, ((2, 'C'), (1, 'C'), (1, 'C'))),
+                (0, False, 0, ((2, 'C'), (1, 'O'), (1, 'O'))),
+
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Cl'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Cl'), (1, 'O'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Br'), (1, 'Br'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Br'), (1, 'O'))),
 
                 (0, False, 0, ((2, 'O'), (2, 'O'), (1, 'O'), (1, 'O'))),
                 (0, False, 0, ((2, 'O'), (2, 'O'), (1, 'Cl'), (1, 'Cl'))),
@@ -280,12 +310,21 @@ class Te(Element, PeriodV, GroupXVI):
     def _valences_exceptions(self):
         return ((0, False, 0, ()),  # elemental,
                 (1, False, 0, ((1, 'C'), (1, 'C'), (1, 'C'))),
+                (-1, False, 0, ((1, 'C'), (1, 'O'), (1, 'Cl'), (1, 'Cl'), (1, 'Cl'))),
                 (1, False, 0, ((1, 'C'), (2, 'C'))),
                 (0, False, 0, ((2, 'O'), (2, 'O'))),
                 (0, False, 0, ((2, 'O'), (1, 'O'), (1, 'O'))),
                 (0, False, 0, ((2, 'O'), (1, 'O'), (1, 'C'))),
                 (0, False, 0, ((2, 'O'), (1, 'C'), (1, 'C'))),
                 (0, False, 0, ((1, 'C'), (1, 'Cl'), (1, 'Cl'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Cl'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'Br'), (1, 'Br'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'O'), (1, 'Cl'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'O'), (1, 'O'))),
+                (0, False, 0, ((1, 'C'), (1, 'C'), (1, 'C'), (1, 'C'))),
+                (0, False, 0, ((1, 'C'), (1, 'O'), (1, 'Cl'), (1, 'Cl'))),
+
+                (0, False, 0, ((1, 'O'), (1, 'O'), (1, 'Cl'), (1, 'Cl'))),
 
                 (0, False, 0, ((2, 'O'), (2, 'O'), (1, 'O'), (1, 'O'))),
                 (0, False, 0, ((1, 'O'), (1, 'O'), (1, 'O'), (1, 'O'), (1, 'O'), (1, 'O'))),
